Examples
========

See the **Example** section for each of these functions:

:func:`cappr.openai.classify.predict`

:func:`cappr.openai.classify.predict_examples`

:func:`cappr.huggingface.classify.predict`

:func:`cappr.huggingface.classify.predict_examples` 

Feel free to `open an issue`_ if you're having trouble with writing a prompt. It's not
always an easy task, and models can be surprisingly finicky.

.. _open an issue: https://github.com/kddubey/cappr/issues
